==> openshift-model-operatorhub-5.2.1-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/StepBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class StepBuilder extends StepFluentImpl<StepBuilder> implements VisitableBuilder<Step,StepBuilder> {

    StepFluent<?> fluent;
    Boolean validationEnabled;

    public StepBuilder() {
        this(true);
    }

    public StepBuilder(Boolean validationEnabled) {
        this(new Step(), validationEnabled);
    }

    public StepBuilder(StepFluent<?> fluent) {
        this(fluent, true);
    }

    public StepBuilder(StepFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Step(), validationEnabled);
    }

    public StepBuilder(StepFluent<?> fluent,Step instance) {
        this(fluent, instance, true);
    }

    public StepBuilder(StepFluent<?> fluent,Step instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withResolving(instance.getResolving()); 
        fluent.withResource(instance.getResource()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public StepBuilder(Step instance) {
        this(instance,true);
    }

    public StepBuilder(Step instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withResolving(instance.getResolving()); 
        this.withResource(instance.getResource()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public Step build() {
        Step buildable = new Step(fluent.getResolving(),fluent.getResource(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        StepBuilder that = (StepBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-operatorhub-5.3.1-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/StepBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class StepBuilder extends StepFluentImpl<StepBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<Step,StepBuilder> {

    StepFluent<?> fluent;
    Boolean validationEnabled;

    public StepBuilder() {
        this(true);
    }

    public StepBuilder(Boolean validationEnabled) {
        this(new Step(), validationEnabled);
    }

    public StepBuilder(StepFluent<?> fluent) {
        this(fluent, true);
    }

    public StepBuilder(StepFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Step(), validationEnabled);
    }

    public StepBuilder(StepFluent<?> fluent,Step instance) {
        this(fluent, instance, true);
    }

    public StepBuilder(StepFluent<?> fluent,Step instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withResolving(instance.getResolving()); 
        fluent.withResource(instance.getResource()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public StepBuilder(Step instance) {
        this(instance,true);
    }

    public StepBuilder(Step instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withResolving(instance.getResolving()); 
        this.withResource(instance.getResource()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public Step build() {
        Step buildable = new Step(fluent.getResolving(),fluent.getResource(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        StepBuilder that = (StepBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
